@@ -3,7 +3,7 @@ import logging
 import time
 
 from .event_handler import EventHandler
-from .rustplus_proto import *
+from .rustplus_proto import AppRequest, AppMessage
 from .rustws import RustWebsocket, CONNECTED, PENDING_CONNECTION
 from .token_bucket import RateLimiter
 from .expo_bundle_handler import MagicValueGrabber
@@ -46,12 +46,12 @@ class RustRemote:
         self.ignored_responses = []
         self.pending_for_response = {}
         self.sent_requests = []
+        self.command_handler = None
 
         if command_options is None:
             self.use_commands = False
         else:
             self.use_commands = True
-            self.command_options = command_options
             self.command_handler = CommandHandler(self.command_options)
 
         self.event_handler = EventHandler()
@@ -90,6 +90,9 @@ class RustRemote:
 
     async def send_message(self, request: AppRequest) -> None:
 
+        if self.ws is None:
+            raise ClientNotConnectedError("No Current Websocket Connection")
+
         await self.ws.send_message(request)
 
     async def get_response(
